---
title: Engineering Success
---

# Engineering Process

# Inspiration & Initial Project(s)
The search for a project topic and goal began once the team was assembled in February, with many ideas put under consideration and discarded over the course of dozens of meetings, literature review and brainstorming. 

In keeping with the tradition of the MSP iGEM teams of the past years, the team chose to focus on combating a local problem. 

Following weeks of brainstorming, the team turned to work on the development of a concept for the synthesis of a biocellulose-chitosan co-polymer. We envisioned this co-polymer could be used to make clothes for astronauts, with functional proteins and enzymes bound to the surface to provide antimicrobial properties. This would ensure a healthier living environment in habitation in space, as well as cut down on the waste and odour of disposable clothes.

This idea evolved into functionalising the co-polymer as a filter and film, and later granules, used for water treatment and filtration, which could double as a fertiliser through recycling into compost. This shift arose as a reaction to several issues of feasibility and efficiency we found with the initial idea, as well as a push to make the idea more local. 

Eventually, the co-polymer concept was discarded, and the team focused on trimming down and finalising details for a concept that could be a winner. 

Finally, the team committed to a concept outline and began work on literature review and background research to prepare for entering the lab work phase of our project. *Vibrio natriegens* was selected as a chassis organism, with the combating eutrophication being selected from the several water treatment focuses possible.

# Purpose
The purpose of the wet lab design was driven by the team’s inspiration, tackling coastal eutrophication with a circular and sustainable approach. Natronaut’s aim is to restore ecosystem balance, mitigating the hypoxic effects of nitrate (NO3-) induced algal bloom and decomposition (Cosme and Hauschild, 2017; Ærtebjerg, 2001). Considering a fully circular approach, the team decided to further extend the project’s purpose to the prevention of  eutrophication development. This would be done by recycling the cells into single-cell proteins, which would supplement animal feeds and lower fertiliser use in traditional animal feed production. 

![**Figure 1.** Project purpose and goals outline. Created with Biorender.com](https://static.igem.wiki/teams/5306/engineering/overallscheme.webp)
**Figure 1.** Project purpose and goals outline. Created with Biorender.com

# Engineering Design & Planning 
## Selection of Chassis Organism 
After finalising the main goals for the project, the team focused on finding the perfect chassis. *Vibrio natriegens* (*V. natriegens*) was deemed the most suitable choice and selected as the chassis organism for the Natronaut project.

Multiple factors played into this decision, but the main inspiration came from a previous iGEM team: the Marburg 2018 *VibriGens.* This team engineered the wildtype strain *ATCC14048* to make it more suitable for research by optimising the strain for cloning, protein expression, and protein interaction studies (Marburg, 2018). 

In addition to the availability of an optimised toolkit for this organism, it was selected in alignment with the purpose of the project: combating coastal eutrophication. A resilient and fast-growing organism that could withstand the high salinity of this environment and provide the increased uptake of nitrates was optimal (Thoma & Blombach, 2021). 

Additionally, its ability to grow on cheap carbon source media, ability to pump proteins into its medium, and finally, the surge in interest for it in the synthetic biology field in the last few years made it an even more appealing option (Weinstock et al., 2016). 

With its robust growth and protein expression capabilities, Natronaut aims to contribute to establishing this strain of *V. natriegens* as a key chassis for synthetic biology, expanding on the *VibriGens* team’s research (Marburg, 2018).

## Designing of The Biological System
**Nitrate Reduction Pathways**
Nitrates can be removed from water through several bacterial metabolic processes. The most prevalent pathway is denitrification, in which NO3- is sequentially reduced to NO2- and then to N2, which is released into the atmosphere (Zhao et al., 2018). Other important nitrate reduction pathways include dissimilatory NO3- reduction to NH4+ (DNRA) and NO3- assimilation (Moreno-Vivián et al., 1999).

DNRA, typically utilised by bacteria in anaerobic conditions for the purposes of energy conservation, involves converting NO3- into NH4+ in a two-step reaction via the NO2- intermediate (Herrmann & Taubert, 2022). While DNRA retains nitrogen in its bioavailable form (NH4+), it does not directly incorporate it into organic compounds. Thus, both denitrification and DNRA result in the loss of available nitrogen - either as atmospheric nitrogen in the case of denitrification or as NH4+ that is not assimilated into biomass in the case of DNRA.

In contrast, the assimilatory NO3- pathway leads to incorporation of nitrogen into organic compounds, such as amino acids, conserving it within the organism (Moreno-Vivián & Flores, 2007; Jiang & Jiao, 2015). These amino acids can be then used to produce SCPs. The assimilatory pathway does not only retain nitrogen, but also contributes to the production of microbial biomass, hence providing a more efficient way of nitrogen utilisation.

The assimilatory pathway in bacteria comprises several steps. First, NO3- is captured and internalised from the extracellular environment to the intracellular space. This step is mediated by a NO3–-transporter, which is most commonly an ATP-binding cassette (ABC)-type transporter located in the cytoplasmic membrane (Moreno-Vivián & Flores, 2007). The transporter consists of three subunits: a periplasmic protein that binds NO3- with high affinity (even at low extracellular concentration of NO3-), a transmembrane protein that facilitates the transport of NO3- across the membrane, and a cytoplasmic ATPase anchored to the membrane, which hydrolyses ATP to provide energy for the process (Lin & Stewart, 1997; Moreno-Vivián & Flores, 2007).

Once the NO3- is internalised, it is then reduced to  NO2- by assimilatory nitrate reductase (Nas). This enzyme is NADH-dependent, and has two subunits: a large catalytic subunit, which contains the essential active site for the reduction of NO3- and a small NADH oxidoreductase subunit, which facilitates the transfer of electrons to the active site  (Lin & Stewart, 1997; Moreno-Vivián & Flores, 2007).  In the following step, NO2- is further reduced to NH4+ by the monomeric nitrite reductase Nir. Afterwards, the produced NH4+ is incorporated into amino acids, specifically glutamine and glutamate through the GS-GOGAT and GDH pathways (Moreno-Vivián & Flores, 2007; van Heeswijk et al., 2013). The GS-GOGAT pathway consists of two key steps. First, the enzyme glutamine synthetase (GS) catalyses an ATP-dependent reaction that converts glutamate to glutamine by incorporating an ammonium ion. Following this, glutamate synthase (GOGAT) transfers the amide group from glutamine to 2-oxoglutarate, resulting in the production of two glutamate molecules. In contrast, the GDH pathway employs a more direct approach. The enzyme glutamate dehydrogenase (GDH) catalyses the incorporation of an ammonium ion (NH₄⁺) directly into 2-oxoglutarate, forming glutamate in a single step. The resulting amino acids, glutamate and glutamine, undergo further transamidation and transamination, yielding various amino acids, which then serve as building blocks for the biosynthesis of proteins during translation (van Heeswijk et al., 2013).

![**Figure 2.** The pathways that result in the biosynthesis of glutamine and glutamate. The GDH pathway is shown in the left panel. The GS-GOGAT pathway is shown in the right panel. Created with BioRender.com](https://static.igem.wiki/teams/5306/gs-gogat.png)
**Figure 2.** The pathways that result in the biosynthesis of glutamine and glutamate. The GDH pathway is shown in the left panel. The GS-GOGAT pathway is shown in the right panel. Created with BioRender.com

![**Figure 3.** Genes in K. oxytoca](https://static.igem.wiki/teams/5306/gs-gogat.png)
**Figure 3.** Genes in K. oxytoca

In K. oxytoca, the genes associated with the nitrate (NO₃⁻) assimilation pathway are arranged in a nasFEDCBA operon. Within this operon, the nasFED gene cluster encodes the transporter necessary for the uptake of extracellular NO₃⁻. Both the membrane-spanning subunit NasE and the ATP-binding subunit NasD play essential roles in the acquisition of nitrate. The genes nasA and nasC encode the large and small subunits of assimilatory nitrate reductase (Nas), respectively, while the nasB gene is linked to nitrite reductase (Nir). This genetic arrangement allows K. oxytoca to efficiently assimilate nitrate (Wu & Stewart, 1998).

A biological system was developed for the uptake and reduction of NO3- into ammonium (NH4+) via a genetically introduced assimilatory reduction pathway (ANRA). The decision to introduce the ANRA pathway into V. natriegens is motivated by a key factor: the pathway is not naturally present in the organism, which restricts its ability to use NO3- as a source of nitrogen (He et al., 2021). By engineering the ANRA pathway, we aim to enhance its metabolic capabilities and enable it to thrive in nitrate-rich environments, such as coastal waters. 

To further leverage this metabolic enhancement, the NH4+ produced from NO3- is then assimilated via the organism’s native GS-GOGAT and NADPH-dependent GDH pathways which enable glutamate (Glu) and glutamine (Gln) biosynthesis (Ohashi et al., 2011; van Heeswijk et al., 2013; Jiang & Jiao, 2016). This self-sustaining biological system supports accelerated growth, transforming V. natriegens into a powerhouse for the production of single-cell protein (SCPs). At the end of the organism’s life cycle, it would have accumulated a high protein content, making it a suitable alternative for livestock feed, reducing the demand for synthetically fertilised crop production.

## Selection of Genes and Genetic Parts
For the construction of this biological system, we selected three key components of the assimilatory nitrate reduction pathway: the nitrate transporter, nitrate reductase (Nas), and nitrite reductase (Nir). These proteins are encoded by a cluster of six genes derived from Klebsiella oxytoca (K. oxytoca) (strain: M5aI) (Wu and Stewart, 1998).

![**Figure 4.** nasFEDCBA operon as seen in K. oxytoca. Sourced from Wu and Stewart, (1998).](https://static.igem.wiki/teams/5306/engineering/nasfedcba-operon.webp)
**Figure 4.** nasFEDCBA operon as seen in K. oxytoca. Sourced from Wu and Stewart, (1998).

These genes were selected for two reasons. First, *K. oxytoca* and *V. natriegens* share taxonomic similarities as they are both Gram-negative bacteria of the class Gammaproteobacteria (Reimer et. al, 2022). This increases the probability of successful gene expression in the chassis organism due to the compatibility of their transcription and translation machinery and similarities in gene expression. Secondly, these genes function as a single operon in *K. oxytoca*, which facilitates their coordinated expression, as all the regulatory elements are retained and proteins produced simultaneously (Wu et al., 1998). This organisation ensures that the components of the ANRA pathway are properly expressed, potentially leading to higher efficiency than combining individual genes from different organisms. 

Initially, the genes were searched for individually on the KEGG and GenBank databases, but we were not able to find all of them, with additional issues caused by identical genes possessing different names within different papers. The amino acid sequences were obtained from the UniProt, and were reverse translated using the [Sequence Manipulation Suite](https://www.bioinformatics.org/sms2/rev_trans.html) online software

This yielded a preliminary nucleotide sequence, although it was not perfect. In order to prepare it, the sequences were copied into the BLAST tool in the Genbank database, which provided us with the accurate sequences. The data was gathered in two files, one for nasFEDC and one for nasBA. 

With these sequences obtained, codon optimisation was carried out in order to adapt them to our chassis organism. 

In previous studies on the nasFEDCBA operon in *K. oxytoca*, RBS sites were found at the end of the coding sequence of each gene. However, these RBS were specific to *K. oxytoca*, which is why their efficacy in *V. natriegens* was uncertain. To ensure their proper functioning, RBS specific to V. natriegens were obtained from the Marburg Collection and inserted before the start codon of each gene. 

Additionally, we sourced a native P1 promoter and a B0015 terminator from the Collection as well, which came together in the following sequence (Figure X.). The promoter and terminator were initially taken from Tschirhart et. al (2019) as they have previosly tested them, and have demonstrated high protein expression levels in *Vibrio natriegens.*

![**Figure 5.** The sequence of genes, including the promoter, terminator, and RBSs selected from the Marburg Collection](https://static.igem.wiki/teams/5306/engineering/genetic-parts-order.webp)
**Figure 5.** The sequence of genes, including the promoter, terminator, and RBSs selected from the Marburg Collection

To ensure the correct folding of the proteins encoded by the identified genes, their three-dimensional structures were simulated using AlphaFold2, an artificial intelligence tool with high accuracy of predicting protein structures based on primary sequences (Yang et al., 2023). Simulations were conducted using the AlphaFold2 Colab notebook. The amino acid sequences (represented in one-letter code) for each protein were entered into the AlphaFold2 pipeline as input. The predicted protein structures were then downloaded in PDB format and analysed using the molecular visualisation software ChimeraX-1.8. The resulting structures of the enzymes and the transporter are illustrated below.

![**Figure 6.** Proteins of interest. Simulated in AlphaFold2, visualised using ChimeraX-1.8.](https://static.igem.wiki/teams/5306/engineering/genetic-parts-order.webp)
**Figure 6.** Proteins of interest. Simulated in AlphaFold2, visualised using ChimeraX-1.8.

The complete sequence of the genes and genetic parts was then divided into fragments smaller than 3000 base, for ordering, with overhangs added for Gibson Assembly.

The team selected Gibson Assembly for the assembly method, judging it as the most applicable to our project, with it’s efficiency in handling large and complex constructs advantageous to obtaining sufficient results. Additionally, research such as the Weinstock et al. (2016) paper and the VibriGens team (Marburg, 2018) proved Gibson Assembly’s efficiency in *V. natriegens* in the past, making this a favourable option.

 The necessary simulations were carried out in SnapGene, and primers were designed for all gBlocks, so more could be made if needed. These were now ready to be ordered as gBlocks from IDT.

 ## Selection of Suitable Plasmid Vector 
 With the selection of the chassis organism and the designing of the pathway and selection of the genes, the search for a suitable vector compatible with the strain began. During research, we considered multiple options for gene delivery. Several factors were taken into account in this process.

Wu and Stewart (1998) found that the genes for the three enzymes of interest work together as a single operon in nature. Therefore, we decided to incorporate the genes coding for the whole nitrate assimilation pathway into one single vector to ensure complete expression and proper native interaction of the parts.

### Traditional Plasmid
For traditional plasmids with independent replication, multiple origins of replication (ORIs) were considered based on the research papers by Tschirhart et al. (2019), as well as Valenzuela-Ortega and French (2021), such as p15a, pBBR1, pJUMP26-1A, and pUC. 

After thorough research on the subject, the team decided to opt for plasmid pSEVA261 with a p15a origin of replication due to its high maintenance, high stability, and low copy number in *Vibrio natriegens* (Tschirhart et al. 2019).

![**Figure 7.** pSEVA261 plasmid. Image taken from SnapGene.](https://static.igem.wiki/teams/5306/engineering/pseva261-map.webp)
**Figure 7.** pSEVA261 plasmid. Image taken from SnapGene.

The team chose to have a low copy number plasmid for this design, as Tschirhart et al. proved that a low copy number did not lead to low maintenance in this case, and overburdening the cells with over-production of such a large plasmid was deemed undesirable.

The chosen pSEVA261 plasmid also has a Kanamycin resistance gene, an antibiotic the team has familiarity working with and was deemed a suitable antibiotic for screening colonies with V. natriegens (Tschirhart et al. 2019). 

Finally, this ORI and plasmid were verified by Tschirhart et al. (2019) to be easily transformable via chemical transformation (also referred to as Heat Shock). This is a method we had selected to use based on the facilities and equipment available to us.

### Integrative Plasmid & Integration Considerations
During a meeting, the team’s secondary PI, David Cortens, pointed out that the large size of the designed plasmid might make it an undesirable burden for the cell leading to low maintenance without a strong selection pressure. 

With the realisation of our assembly totalling an excess of 12k base pairs, we considered the idea of integrating the genes into the genome of *V. natriegens*, for two primary reasons. 

Firstly, this would offload the strain of plasmid maintenance off of the cells, making sure that the cells don’t drop the plasmid in absence of antibiotic-supplemented medium. Secondly, as a result, this would allow us to not require the supplementation of the media used with antibiotics. 

For the integration of the operon, three different techniques mediating integration were considered: 

- A joint universal modular plasmid (JUMP) with an R6K ORI,
- overexpression of a tfoX gene, inducing natural competence, or
- the use of serine integrases.

After background research was done for all considered options, see the “Genomic Integration” module, the team decided to use the serine integrases to insert a GFP gene to test the success of the integration followed by a DNA cassette exchange to insert the desired operon. Due to time constraints the team was unable to carry out this research in the wet lab, however, with all the background research and design considerations the team had being listed in detail below in the “Genomic Integration” module. 

This kind of thinking ahead and considering of the later stages of development and engineering of the organism and application were constantly on our minds as we worked on the project. 

With these considerations, and research completed, pSEVA261 was deemed the ideal plasmid for this project.

# Summary
Following extensive literature review and brainstorming, the team completed the initial version of the design seen above, a framework from which our experimentation could begin and lab work could be set into motion. Protocols were gathered from the resources gathered from the literature review and adapted to suit the facilities at our disposal, and g-blocks, cells and plasmid ordered, in order to begin the next phase of the project, the Design Build Test Learn (DBTL) cycles. 

*With the literature review and dry lab research completed, the gears of the DBTL cycles could begin to turn…*
# DBTL Cycles
The design, build, test, learn (DBTL) is an important component of engineering as as much extends to genetic engineering as well. We have successfully completed multiple DBTL cycles.
<IterativeCycle />

